@@ -36,7 +36,9 @@ class Mangadex(Site):
                 cover = rel["attributes"]["fileName"]
 
         descriptions = attrs["description"]
-        if "en" in descriptions:
+        if not descriptions:
+            description = ""
+        elif "en" in descriptions:
             description = descriptions["en"]
         else:
             description = list(descriptions.values())[0]
@@ -47,7 +49,9 @@ class Mangadex(Site):
             "site": "mangadex",
             "cover_ext": cover,
             "alt_names": [list(alt.values())[0] for alt in attrs["altTitles"]],
-            "descriptions": [_bbparser.format(html.unescape(description).strip())],
+            "descriptions": [_bbparser.format(html.unescape(description).strip())]
+            if description
+            else [],
             "descriptions_format": "html",
             "is_webtoon": is_web_comic,
             "chapters": self.get_chapters_list(title_id),
@@ -102,14 +106,17 @@ class Mangadex(Site):
             if rel["type"] == "manga":
                 title_id = rel["id"]
                 break
-
-        chapter_hash = data["attributes"]["hash"]
-        filenames = data["attributes"]["data"]
+        # chapter_hash = data["attributes"]["hash"]
+        # filenames = data["attributes"]["data"]
         md_server = "https://uploads.mangadex.org"
 
-        mdah_server = self._get_md_at_home_server(chapter_id)
-        if mdah_server != md_server:
-            print(">> MDAH-server:", mdah_server)
+        mdah_api_url = f"https://api.mangadex.org/at-home/server/{chapter_id}"
+        mdah_resp = self.http_get(mdah_api_url)
+        assert mdah_resp.status_code == 200, f"Failed request to {mdah_api_url}"
+        mdah_data = mdah_resp.json()
+        mdah_server = mdah_data["baseUrl"]
+        chapter_hash = mdah_data["chapter"]["hash"]
+        filenames = mdah_data["chapter"]["data"]
 
         chapter = {
             "id": chapter_id,
@@ -130,10 +137,6 @@ class Mangadex(Site):
         }
         return chapter
 
-    def _get_md_at_home_server(self, chapter_id):
-        resp = self.http_get(f"https://api.mangadex.org/at-home/server/{chapter_id}")
-        return resp.json()["baseUrl"] if resp.status_code == 200 else None
-
     def search_title(self, query):
         params = {
             "limit": 100,
